## 同花顺概念和行业指数

接口：ths_index

描述：获取同花顺板块指数。注：数据版权归属同花顺，如做商业用途，请主动联系同花顺，如需帮助请联系微信：waditu_a

权限：本接口需有6000积分，单次最大返回5000行数据，一次可提取全部数据，请勿循环提取。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 指数代码 |
| exchange | str | N | 市场类型A-a股 HK-港股 US-美股 |
| type | str | N | 指数类型 N-概念指数 I-行业指数 R-地域指数 S-同花顺特色指数 ST-同花顺风格指数 TH-同花顺主题指数 BB-同花顺宽基指数 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 代码 |
| name | str | Y | 名称 |
| count | int | Y | 成分个数 |
| exchange | str | Y | 交易所 |
| list_date | str | Y | 上市日期 |
| type | str | Y | N概念指数S特色指数 |

接口示例

```python
pro = ts.pro_api()

df = pro.ths_index()
```

数据样例

```python
ts_code     name       count exchange list_date type
0    885835.TI     参股银行    126        A  20190416    N
```